#     Copyright 2012, Kay Hayen, mailto:kayhayen@gmx.de
#
#     Part of "Nuitka", an optimizing Python compiler that is compatible and
#     integrates with CPython, but also works on its own.
#
#     Licensed under the Apache License, Version 2.0 (the "License");
#     you may not use this file except in compliance with the License.
#     You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#     Unless required by applicable law or agreed to in writing, software
#     distributed under the License is distributed on an "AS IS" BASIS,
#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#     See the License for the specific language governing permissions and
#     limitations under the License.
#
""" For and while loop related templates.

"""

template_loop_break_continue_catching = """\
while( true )
{
    try
    {
%(loop_body_codes)s
    }
    catch( ContinueException & )
    { /* Nothing to do */
    }
    catch ( BreakException & )
    { /* Break the loop */
       break;
    }
}"""

template_loop_break_catching = """\
while( true )
{
    try
    {
%(loop_body_codes)s
    }
    catch ( BreakException & )
    { /* Break the loop */
       break;
    }
}"""

template_loop_continue_catching = """\
while( true )
{
    try
    {
%(loop_body_codes)s
    }
    catch( ContinueException & )
    { /* Nothing to do */
    }
}"""

template_loop_simple = """\
while( true )
{
%(loop_body_codes)s
}"""
